import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { optionsListApi,optionsListApiType } from '/@/api/tigerapi/mes/smt/smttable';
import { h,unref } from 'vue';
import { Tag ,Tooltip} from 'ant-design-vue';
import{ useLocale } from '/@/locales/useLocale';

const { getLocale }=useLocale();

export const searchFormSchema: FormSchema[] = [
  {
    field: 'LINE_CODE',
    label: '线别',
    colProps: {
      span: 8,
    },
    component: 'ApiSelect',
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: 'LINE_NAME',
      valueField: 'LINE_CODE',
    },
  },
  {
    field: 'SMT_CODE',
    component: 'Input',
    label: '机台',
    colProps: {
      span: 8,
    },
  },
  {
    field: 'PCB_SURFACE',
    component: 'Switch',
    label: '正反面',
    colProps: {
      span: 8,
    },
  },
];

export const columns: BasicColumn[] = [
  {
    title: '关联工单号',
    dataIndex: 'WORK_ORDER',
    width: 180,
  },
  {
    title: '产品编码',
    dataIndex: 'PROD_CODE',
    width: 180,
  },
  {
    title: '物料编码',
    dataIndex: 'ITEM_CODE',
    width: 180,
  },
  {
    title: '替代料',
    dataIndex: 'SUBITEM_CODE',
    width: 180,
  },
  {
    title: '单位',
    dataIndex: 'UNIT',
    width: 180,
  },
  {
    title: '单位用量',
    dataIndex: 'UNIT_QTY',
    width: 180,
  },
  {
    title: '产线编码',
    dataIndex: 'LINE_CODE',
    width: 180,
  },
  {
    title: '贴片机编码',
    dataIndex: 'SMT_CODE',
    width: 180,
  },
  {
    title: '钢网编码',
    dataIndex: 'SMT_STENCIL',
    width: 180,
  },
  {
    title: '站位号',
    dataIndex: 'SLOT_NO',
    width: 180,
  },
  {
    title: '贴片位置',
    dataIndex: 'LOCATION',
    width: 180,
  },
  {
    title: '飞达编码',
    dataIndex: 'FEEDER_CODE',
    width: 180,
  },
  {
    title: '飞达类型',
    dataIndex: 'FEEDER_TYPE',
    width: 180,
  },
  {
    title: '加工面',
    dataIndex: 'PCB_SURFACE',
    width: 180,
  },
  {
    title: '上料顺序',
    dataIndex: 'LOAD_SEQ',
    width: 180,
  },
  {
    title: '创建人',
    dataIndex: 'CREATE_USER',
    width: 180,
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'REMARK',
    width: 180,
  },
];

//新增组件export const
export const formSchema: FormSchema[] = [
  {
    field: 'WORK_ORDER',
    label: '关联工单号',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'PROD_CODE',
    label: '产品编码',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ITEM_CODE',
    label: '物料编码',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SUBITEM_CODE',
    label: '替代料',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'UNIT',
    label: '单位',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'UNIT_QTY',
    label: '单位用量',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'LINE_CODE',
    label: '产线编码',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SMT_CODE',
    label: '贴片机编码',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SMT_STENCIL',
    label: '钢网编码',
    //required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SLOT_NO',
    label: '站位号',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'LOCATION',
    label: '贴片位置',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'FEEDER_CODE',
    label: '飞达编码',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'FEEDER_TYPE',
    label: '飞达类型',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'PCB_SURFACE',
    label: '加工面',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: 'A面',
          value: 'A面',
          key: 'A面',
        },
        {
          label: 'B面',
          value: 'B面',
          key: 'B面',
        },
      ],
    },
  },
  {
    field: 'LOAD_SEQ',
    label: '上料顺序',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'REMARK',
    label: '备注',
    component: 'Input',
    colProps: { span: 8 },
  },
];
